@@ -236,7 +236,10 @@ class SessionTest(BaseSessionTest):
 
     def test_emit_delegates_to_emitter(self):
         calls = []
-        handler = lambda **kwargs: calls.append(kwargs)
+
+        def handler(**kwargs):
+            return calls.append(kwargs)
+
         self.session.register('foo', handler)
         self.session.emit('foo')
         self.assertEqual(len(calls), 1)
@@ -248,7 +251,10 @@ class SessionTest(BaseSessionTest):
             session_vars=self.env_vars, event_hooks=events
         )
         calls = []
-        handler = lambda **kwargs: calls.append(kwargs)
+
+        def handler(**kwargs):
+            return calls.append(kwargs)
+
         events.register('foo', handler)
 
         session.emit('foo')
@@ -283,7 +289,10 @@ class SessionTest(BaseSessionTest):
 
     def test_register_with_unique_id(self):
         calls = []
-        handler = lambda **kwargs: calls.append(kwargs)
+
+        def handler(**kwargs):
+            return calls.append(kwargs)
+
         self.session.register('foo', handler, unique_id='bar')
         self.session.emit('foo')
         self.assertEqual(calls[0]['event_name'], 'foo')
@@ -584,6 +593,7 @@ class TestCreateClient(BaseSessionTest):
             scoped_config=mock.ANY,
             client_config=config,
             api_version=mock.ANY,
+            auth_token=mock.ANY,
         )
 
     @mock.patch('botocore.client.ClientCreator')
@@ -602,6 +612,7 @@ class TestCreateClient(BaseSessionTest):
             scoped_config=mock.ANY,
             client_config=config,
             api_version=mock.ANY,
+            auth_token=mock.ANY,
         )
 
     @mock.patch('botocore.client.ClientCreator')
@@ -721,7 +732,7 @@ class TestCreateClient(BaseSessionTest):
             f.write('[default]\n')
             f.write(
                 'foo_api_versions =\n'
-                '    myservice = %s\n' % config_api_version
+                f'    myservice = {config_api_version}\n'
             )
             f.flush()
 
@@ -772,7 +783,7 @@ class TestCreateClient(BaseSessionTest):
             f.write('[default]\n')
             f.write(
                 'foo_api_versions =\n'
-                '    myservice = %s\n' % config_api_version
+                f'    myservice = {config_api_version}\n'
             )
             f.flush()
 
@@ -793,9 +804,7 @@ class TestSessionComponent(BaseSessionTest):
             self.session._get_internal_component('internal'), component
         )
         with self.assertRaises(ValueError):
-            # get_component has been deprecated to the public
-            with pytest.warns(DeprecationWarning):
-                self.session.get_component('internal')
+            self.session.get_component('internal')
 
     def test_internal_endpoint_resolver_is_same_as_deprecated_public(self):
         endpoint_resolver = self.session._get_internal_component(
@@ -842,14 +851,20 @@ class TestComponentLocator(unittest.TestCase):
 
     def test_can_lazy_register_a_component(self):
         component = object()
-        lazy = lambda: component
+
+        def lazy():
+            return component
+
         self.components.lazy_register_component('foo', lazy)
         self.assertIs(self.components.get_component('foo'), component)
 
     def test_latest_registration_wins_even_if_lazy(self):
         first = object()
         second = object()
-        lazy_second = lambda: second
+
+        def lazy_second():
+            return second
+
         self.components.register_component('foo', first)
         self.components.lazy_register_component('foo', lazy_second)
         self.assertIs(self.components.get_component('foo'), second)
@@ -857,7 +872,10 @@ class TestComponentLocator(unittest.TestCase):
     def test_latest_registration_overrides_lazy(self):
         first = object()
         second = object()
-        lazy_first = lambda: first
+
+        def lazy_first():
+            return first
+
         self.components.lazy_register_component('foo', lazy_first)
         self.components.register_component('foo', second)
         self.assertIs(self.components.get_component('foo'), second)
